package
module
Version:
v0.0.0-...-e077229
Opens a new window with list of versions in this module.
Published: Apr 5, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Node struct {
Next *Node
Value Data
}
type Queue interface {
Enqueue(obj Data)
Dequeue() Data
IsEmpty() bool
Size() int
Iterate() <-chan Data
}
func NewQueueLinkedList() Queue
Source Files
¶
Click to show internal directories.
Click to hide internal directories.