package
module
Version:
v0.0.0-...-e077229
Opens a new window with list of versions in this module.
Published: Apr 5, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Stack interface {
Push(item Data)
Pop() Data
IsEmpty() bool
Size() int
Iterate() <-chan Data
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.